==> react-grid-layout-0.16.0-0.jar: cljsjs/react-grid-layout/common/react-grid-layout.ext.js <==
// Generated via http://jmmk.github.io/javascript-externs-generator/

// Loaded JavaScripts:
// https://github.com/facebook/react/releases/download/v16.0.0/react.production.min.js
// https://rawgit.com/STRML/react-grid-layout/0.16.0/dist/react-grid-layout.min.js

// Reference ns as ReactGridLayout
var ReactGridLayout = {
  "Responsive": {
    "defaultProps": {
      "breakpoints": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "cols": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "layouts": {},
      "onBreakpointChange": function () {},
      "onLayoutChange": function () {},
      "onWidthChange": function () {}
    },
    "propTypes": {
      "breakpoint": {
        "isRequired": function () {}
      },
      "breakpoints": {
        "isRequired": function () {}
      },
      "cols": {
        "isRequired": function () {}
      },
      "layouts": function () {},
      "onBreakpointChange": {
        "isRequired": function () {}
      },
      "onLayoutChange": {
        "isRequired": function () {}
      },
      "onWidthChange": {
        "isRequired": function () {}
      },
      "width": {
        "isRequired": function () {}
      }
    },
    "utils": {
      "__esModule": {},
      "findOrGenerateResponsiveLayout": function () {},
      "getBreakpointFromWidth": function () {},
      "getColsFromBreakpoint": function () {},
      "sortBreakpoints": function () {}
    }
  },
  "WidthProvider": function () {},
  "defaultProps": {
    "autoSize": {},
    "className": {},
    "cols": {},
    "compactType": {},
    "isDraggable": {},
    "isResizable": {},
    "layout": {},
    "margin": {},
    "maxRows": {},
    "onDrag": function () {},
    "onDragStart": function () {},
    "onDragStop": function () {},
    "onLayoutChange": function () {},
    "onResize": function () {},
    "onResizeStart": function () {},
    "onResizeStop": function () {},
    "preventCollision": {},
    "rowHeight": {},
    "useCSSTransforms": {},
    "verticalCompact": {}
  },
  "displayName": {},
  "propTypes": {
    "autoSize": {
      "isRequired": function () {}
    },
    "children": function () {},
    "className": {
      "isRequired": function () {}
    },
    "cols": {
      "isRequired": function () {}
    },
    "compactType": {
      "isRequired": function () {}
    },
    "containerPadding": {
      "isRequired": function () {}
    },
    "draggableCancel": {
      "isRequired": function () {}
    },
    "draggableHandle": {
      "isRequired": function () {}
    },
    "isDraggable": {
      "isRequired": function () {}
    },
    "isResizable": {
      "isRequired": function () {}
    },
    "layout": function () {},
    "margin": {
      "isRequired": function () {}
    },
    "maxRows": {
      "isRequired": function () {}
    },
    "onDrag": {
      "isRequired": function () {}
    },
    "onDragStart": {
      "isRequired": function () {}
    },
    "onDragStop": {
      "isRequired": function () {}
    },
    "onLayoutChange": {
      "isRequired": function () {}
    },
    "onResize": {
      "isRequired": function () {}
    },
    "onResizeStart": {
      "isRequired": function () {}
    },
    "onResizeStop": {
      "isRequired": function () {}
    },
    "preventCollision": {
      "isRequired": function () {}
    },
    "rowHeight": {
      "isRequired": function () {}
    },
    "style": {
      "isRequired": function () {}
    },
    "useCSSTransforms": {
      "isRequired": function () {}
    },
    "verticalCompact": function () {},
    "width": {
      "isRequired": function () {}
    }
  },
  "utils": {
    "__esModule": {},
    "autoBindHandlers": function () {},
    "bottom": function () {},
    "childrenEqual": function () {},
    "cloneLayout": function () {},
    "cloneLayoutItem": function () {},
    "collides": function () {},
    "compact": function () {},
    "compactItem": function () {},
    "correctBounds": function () {},
    "getAllCollisions": function () {},
    "getFirstCollision": function () {},
    "getLayoutItem": function () {},
    "getStatics": function () {},
    "moveElement": function () {},
    "moveElementAwayFromCollision": function () {},
    "perc": function () {},
    "setTopLeft": function () {},
    "setTransform": function () {},
    "sortLayoutItems": function () {},
    "sortLayoutItemsByColRow": function () {},
    "sortLayoutItemsByRowCol": function () {},
    "synchronizeLayoutWithChildren": function () {},
    "validateLayout": function () {}
  }
};
ReactGridLayout.prototype = {
  "compactType": function () {},
  "componentDidMount": function () {},
  "componentWillReceiveProps": function () {},
  "containerHeight": function () {},
  "forceUpdate": function () {},
  "isReactComponent": function () {},
  "onDrag": function () {},
  "onDragStart": function () {},
  "onDragStop": function () {},
  "onLayoutMaybeChanged": function () {},
  "onResize": function () {},
  "onResizeStart": function () {},
  "onResizeStop": function () {},
  "placeholder": function () {},
  "processGridItem": function () {},
  "render": function () {},
  "setState": function () {}
};
ReactGridLayout.Responsive.prototype = {
  "componentWillReceiveProps": function () {},
  "forceUpdate": function () {},
  "generateInitialState": function () {},
  "isReactComponent": function () {},
  "onWidthChange": function () {},
  "render": function () {},
  "setState": function () {}
};
/**********************************************************************
 * End Generated Extern for ReactGridLayout
/**********************************************************************/

==> react-grid-layout-0.16.6-0.jar: cljsjs/react-grid-layout/common/react-grid-layout.ext.js <==
// Generated via http://jmmk.github.io/javascript-externs-generator/

// Loaded JavaScripts:
// https://github.com/facebook/react/releases/download/v16.0.0/react.production.min.js
// https://rawgit.com/STRML/react-grid-layout/0.16.5/dist/react-grid-layout.min.js

// Reference ns as ReactGridLayout
var ReactGridLayout = {
  "Responsive": {
    "defaultProps": {
      "breakpoints": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "cols": {
        "lg": {},
        "md": {},
        "sm": {},
        "xs": {},
        "xxs": {}
      },
      "layouts": {},
      "onBreakpointChange": function () {},
      "onLayoutChange": function () {},
      "onWidthChange": function () {}
    },
    "propTypes": {
      "breakpoint": {
        "isRequired": function () {}
      },
      "breakpoints": {
        "isRequired": function () {}
      },
      "cols": {
        "isRequired": function () {}
      },
      "layouts": function () {},
      "onBreakpointChange": {
        "isRequired": function () {}
      },
      "onLayoutChange": {
        "isRequired": function () {}
      },
      "onWidthChange": {
        "isRequired": function () {}
      },
      "width": {
        "isRequired": function () {}
      }
    },
    "utils": {
      "__esModule": {},
      "findOrGenerateResponsiveLayout": function () {},
      "getBreakpointFromWidth": function () {},
      "getColsFromBreakpoint": function () {},
      "sortBreakpoints": function () {}
    }
  },
  "WidthProvider": function () {},
  "defaultProps": {
    "autoSize": {},
    "className": {},
    "cols": {},
    "compactType": {},
    "containerPadding": {},
    "draggableCancel": {},
    "draggableHandle": {},
    "isDraggable": {},
    "isResizable": {},
    "layout": {},
    "margin": {},
    "maxRows": {},
    "onDrag": function () {},
    "onDragStart": function () {},
    "onDragStop": function () {},
    "onLayoutChange": function () {},
    "onResize": function () {},
    "onResizeStart": function () {},
    "onResizeStop": function () {},
    "preventCollision": {},
    "rowHeight": {},
    "style": {},
    "useCSSTransforms": {},
    "verticalCompact": {}
  },
  "displayName": {},
  "propTypes": {
    "autoSize": {
      "isRequired": function () {}
    },
    "children": function () {},
    "className": {
      "isRequired": function () {}
    },
    "cols": {
      "isRequired": function () {}
    },
    "compactType": {
      "isRequired": function () {}
    },
    "containerPadding": {
      "isRequired": function () {}
    },
    "draggableCancel": {
      "isRequired": function () {}
    },
    "draggableHandle": {
      "isRequired": function () {}
    },
    "isDraggable": {
      "isRequired": function () {}
    },
    "isResizable": {
      "isRequired": function () {}
    },
    "layout": function () {},
    "margin": {
      "isRequired": function () {}
    },
    "maxRows": {
      "isRequired": function () {}
    },
    "onDrag": {
      "isRequired": function () {}
    },
    "onDragStart": {
      "isRequired": function () {}
    },
    "onDragStop": {
      "isRequired": function () {}
    },
    "onLayoutChange": {
      "isRequired": function () {}
    },
    "onResize": {
      "isRequired": function () {}
    },
    "onResizeStart": {
      "isRequired": function () {}
    },
    "onResizeStop": {
      "isRequired": function () {}
    },
    "preventCollision": {
      "isRequired": function () {}
    },
    "rowHeight": {
      "isRequired": function () {}
    },
    "style": {
      "isRequired": function () {}
    },
    "useCSSTransforms": {
      "isRequired": function () {}
    },
    "verticalCompact": function () {},
    "width": {
      "isRequired": function () {}
    }
  },
  "utils": {
    "__esModule": {},
    "autoBindHandlers": function () {},
    "bottom": function () {},
    "childrenEqual": function () {},
    "cloneLayout": function () {},
    "cloneLayoutItem": function () {},
    "collides": function () {},
    "compact": function () {},
    "compactItem": function () {},
    "correctBounds": function () {},
    "getAllCollisions": function () {},
    "getFirstCollision": function () {},
    "getLayoutItem": function () {},
    "getStatics": function () {},
    "moveElement": function () {},
    "moveElementAwayFromCollision": function () {},
    "noop": function () {},
    "perc": function () {},
    "setTopLeft": function () {},
    "setTransform": function () {},
    "sortLayoutItems": function () {},
    "sortLayoutItemsByColRow": function () {},
    "sortLayoutItemsByRowCol": function () {},
    "synchronizeLayoutWithChildren": function () {},
    "validateLayout": function () {}
  }
};
ReactGridLayout.prototype = {
  "compactType": function () {},
  "componentDidMount": function () {},
  "componentWillReceiveProps": function () {},
  "containerHeight": function () {},
  "forceUpdate": function () {},
  "isReactComponent": function () {},
  "onDrag": function () {},
  "onDragStart": function () {},
  "onDragStop": function () {},
  "onLayoutMaybeChanged": function () {},
  "onResize": function () {},
  "onResizeStart": function () {},
  "onResizeStop": function () {},
  "placeholder": function () {},
  "processGridItem": function () {},
  "render": function () {},
  "setState": function () {}
};
ReactGridLayout.Responsive.prototype = {
  "componentWillReceiveProps": function () {},
  "forceUpdate": function () {},
  "generateInitialState": function () {},
  "isReactComponent": function () {},
  "onWidthChange": function () {},
  "render": function () {},
  "setState": function () {}
};
/**********************************************************************
 * End Generated Extern for ReactGridLayout
/**********************************************************************/
